@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 
 # ABSTRACT: create form fields based on a definition in a JSON file
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 use File::Basename;
@@ -652,7 +652,7 @@ Mojolicious::Plugin::FormFieldsFromJSON - create form fields based on a definiti
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -896,10 +896,20 @@ Those fields have the following definition items in common:
 
 =over 4
 
+=item * name
+
+The name of the field. If you do not pass an id for the field in the I<attributes>-field, the name is also
+taken for the field id.
+
 =item * label
 
+If a template is used, this value is passed for C<$label>. If the translation feature is used, the label
+is translated.
+
 =item * type
 
+One of the above mentioned types. Please note, that you can add own types.
+
 =item * data
 
 For I<text>, I<textarea>, I<password> and I<hidden> this is the value for the field. This can be set in various ways:
@@ -924,7 +934,24 @@ For I<select>, I<checkbox> and I<radio> fields, I<data> contains the possible va
 
 =item * attributes
 
-Attributes of the field like "class"
+Attributes of the field like "class":
+
+  attributes => {
+    class => 'button'
+  }
+
+If I<global_attributes> are defined, then the values are added, so that
+
+  plugin( 'FormFieldsFromJSON' => {
+    global_attributes => {
+      class => 'button-danger',
+    }
+  });
+
+and the I<attributes> field as shown, then the field has two classes: I<button> and I<button-danger>. In the
+field the classes mentioned in field config come first.
+
+  <button class="button button-danger" ...>
 
 =back
 
@@ -1966,7 +1993,7 @@ Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Renee Baecker.
+This software is Copyright (c) 2015 by Renee Baecker.
 
 This is free software, licensed under:
 
